NLSL: stdio Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
stdio Module Reference

## Variables
integer, parameter | lulog =4
integer, parameter | luttyi =5
integer, parameter | luttyo =6
integer, parameter | lutrc =7
integer, parameter | ludisk =8
integer, save | lucmd
integer, save | luecho
integer, save | luout
integer, save | hltcmd
integer, save | hltfit
integer, save | itrace
logical, save | warn

## Variable Documentation

integer, save stdio::hltcmd

Definition at line 32 of file stdio.f90.

integer, save stdio::hltfit

Definition at line 32 of file stdio.f90.

integer, save stdio::itrace

Definition at line 32 of file stdio.f90.

integer, save stdio::lucmd

Definition at line 32 of file stdio.f90.

integer, parameter stdio::ludisk =8

Definition at line 29 of file stdio.f90.

integer, save stdio::luecho

Definition at line 32 of file stdio.f90.

integer, parameter stdio::lulog =4

Definition at line 29 of file stdio.f90.

integer, save stdio::luout

Definition at line 32 of file stdio.f90.

integer, parameter stdio::lutrc =7

Definition at line 29 of file stdio.f90.

integer, parameter stdio::luttyi =5

Definition at line 29 of file stdio.f90.

integer, parameter stdio::luttyo =6

Definition at line 29 of file stdio.f90.

logical, save stdio::warn

Definition at line 33 of file stdio.f90.